@@ -1,3 +1,5 @@
+import math
+import queue
 import traceback
 from collections import UserDict
 from http.server import SimpleHTTPRequestHandler
@@ -13,8 +15,10 @@ class KartObserver(Observer):
                 self.dispatch_events(self.event_queue, self.timeout)
                 if self.event_queue.empty():
                     self.action()
+            except queue.Empty:
+                pass
             except Exception:
-                continue
+                print(traceback.format_exc())
 
 
 class KartRequesHandler(SimpleHTTPRequestHandler):
@@ -49,7 +53,7 @@ def paginate(objects, per_page, template, base_url, slug, additional_data={}):
     urls = {}
     paginated_objects = [
         objects[x * per_page : (x + 1) * per_page]
-        for x in range(len(objects) // per_page + 1)
+        for x in range(max(math.ceil(len(objects) / per_page), 1))
     ]
     for i, objects in enumerate(paginated_objects, 1):
         url = f"/{i}/" if i > 1 else "/"
@@ -89,3 +93,15 @@ def slug_from_path(base_dir, path):
     path = str(path)[: -len(path.suffix)]
     result = slugify(path)
     return path  # result
+
+
+def merge_dicts(a, b):
+    for key in b:
+        if key not in a:
+            a[key] = b[key]
+        else:
+            if isinstance(b[key], dict):
+                if isinstance(a[key], dict):
+                    merge_dicts(a[key], b[key])
+                else:
+                    raise Exception
